@@ -1,5 +1,4 @@
 law.plot2d <- function(data,density=FALSE,densfunc=dnorm,probfunc=pnorm,tinf=-5,tsup=5) {
-
   
   nmax <- ncol(data)
   M <- nrow(data)
@@ -16,7 +15,7 @@ law.plot2d <- function(data,density=FALSE,densfunc=dnorm,probfunc=pnorm,tinf=-5,
     else {
       curve(probfunc,xlim=c(tinf,tsup),xlab="",ylab="",main="")
       par(new=TRUE)
-      plot.ecdf(ecdf(data[,nn]),p="",xlim=c(tinf,tsup),col.h="red",xlab="t",ylab=expression(F~"(t) and " ~ hat(F)[n]~"(t)"),main="Convergence in law?")
+      plot.ecdf(ecdf(data[,nn]),do.points=FALSE,xlim=c(tinf,tsup),col.h="red",xlab="t",ylab=expression(F~"(t) and " ~ hat(F)[n]~"(t)"),main="Convergence in law?")
       legend(x=tinf, y=1, legend=c("F(t)",expression(hat(F)[n](t))), col = c("black","red"),lty=1)
     }				}
                  )
